==> fd-faq-900.0-noarch-1.txz: usr/share/doc/fd-faq/defaults.md <==
%%textdomain fatdoghelp

 
![Fatdog64 logo](img/fatdog64-header.png)

#  
# How to change programs used as default?
#  

**Question:** I have installed another web browser. How do I change it so that it is the one used as default?

**Answer:** Edit /etc/defaultprograms with your favorite text editor and change the entries there. To change default browser from "*seamonkey-spot*" to firefox (without spot), for example, change the DEF\_BROWSER entry in that file and replace the text within quotes. You can do the same for the rest of the applications listed there: draw, html editor, paint, media player, etc.

Since Fatdog64-710 Beta you can also use "Fatdog64 Edit Default Programs" GUI available in Control Panel on "System" tab ("Desktop" tab on older Fatdogs). This method changes the default applications on per-user basis (~/.fatdog/defaultprograms).

**Note**: Doing this will only change the defaults for programs that honour Puppy-like model of default programs.

Unfortunately there are no single unified way to change the "default" programs unless you run a comprehensive desktop environment like KDE or Gnome. Every program has its own way of keeping track of what it thinks as the *default*.

XDG-compliant programs, for example SpaceFM, make use of /usr/share/applications/mimeapps.list and /usr/share/applications/defaults.list (see [http:`//standards.freedesktop.org/mime-apps-spec/mime-apps-spec-1.0.html`](http://standards.freedesktop.org/mime-apps-spec/mime-apps-spec-1.0.html) for details). Other file managers like XFE or ROX-Filer has its own way of keeping default programs. You will have consult the documentation of each individual program if the method described above doesn't seem to work.


----

[Fatdog64](home.md)
| [FAQ index](faq.md)
| [FAQ files](faq_file_list.md)
| [Fatdog64 online](https://distro.ibiblio.org/fatdog/web)
| [FAQ online](https://distro.ibiblio.org/fatdog/web/faqs/faq.html)

----

_This page was automatically converted from [defaults.html](https://distro.ibiblio.org/fatdog/web/faqs/defaults.html) on 2023-09-08._

==> fd-faq-901.0-noarch-1.txz: usr/share/doc/fd-faq/defaults.md <==
%%textdomain fatdoghelp

 
![Fatdog64 logo](img/fatdog64-header.png)

#  
# How to change programs used as default?
#  

**Question:** I have installed another web browser. How do I change it so that it is the one used as default?

**Answer:** Edit /etc/defaultprograms with your favorite text editor and change the entries there. To change default browser from "*seamonkey-spot*" to firefox (without spot), for example, change the DEF\_BROWSER entry in that file and replace the text within quotes. You can do the same for the rest of the applications listed there: draw, html editor, paint, media player, etc.

Since Fatdog64-710 Beta you can also use "Fatdog64 Edit Default Programs" GUI available in Control Panel on "System" tab ("Desktop" tab on older Fatdogs). This method changes the default applications on per-user basis (~/.fatdog/defaultprograms).

**Note**: Doing this will only change the defaults for programs that honour Puppy-like model of default programs.

Unfortunately there are no single unified way to change the "default" programs unless you run a comprehensive desktop environment like KDE or Gnome. Every program has its own way of keeping track of what it thinks as the *default*.

XDG-compliant programs, for example SpaceFM, make use of /usr/share/applications/mimeapps.list and /usr/share/applications/defaults.list (see <http://standards.freedesktop.org/mime-apps-spec/mime-apps-spec-1.0.html> for details). Other file managers like XFE or ROX-Filer has its own way of keeping default programs. You will have consult the documentation of each individual program if the method described above doesn't seem to work.


----

[Fatdog64](home.md)
| [FAQ index](faq.md)
| [FAQ files](faq_file_list.md)
| [Fatdog64 online](https://distro.ibiblio.org/fatdog/web)
| [FAQ online](https://distro.ibiblio.org/fatdog/web/faqs/faq.html)

----

_This page was automatically converted from [defaults.html](https://distro.ibiblio.org/fatdog/web/faqs/defaults.html) on 2023-10-09._
